/// <reference types="node" />
import * as Http from "http";
import * as Https from "https";
export declare class FetchEx extends Error {
    readonly statusCode?: number;
    constructor(message: string, statusCode?: number, data?: string);
}
export declare class Fetch {
    protected readonly _options: Https.RequestOptions;
    /**
     * creates new instance of `Fetch` bound to given url
     * @param url url
     */
    constructor(url: string, options?: Https.RequestOptions);
    /**
     * sets request timeout (by default timeout is auto-set for 20 seconds)
     * @param ms timeout in miliseconds
     */
    timeout(ms: number): this;
    /**
     * setup https options
     * @param key
     * @param cert
     */
    cert(key: string, cert: string): this;
    /**
     * sets request header
     * @param key key
     * @param value value
     */
    head(key: string, value: any): this;
    /**
     * use to ignore https certificate issues
     */
    unauthorized(): this;
    /**
     * sets basic authorization header to given user/password
     * @param user user
     * @param password password
     */
    basicAuth(user: string, password: string): this;
    /**
     * set bearer authorization header to given token
     * @param token token
     */
    bearerAuth(token: string): this;
    private initRequest;
    private _respHeaders;
    /** get last response headers */
    get respHeaders(): Http.IncomingHttpHeaders;
    /**
     * sends request with optional content
     * @param content content
     * @param contentType content type, by default `application/json`
     * @param method http method, by default `GET` (or `POST` if content is set)
     * @param encoding by default `utf8`
     * @async
     */
    fetch(content?: string | Buffer, contentType?: string, method?: string, encoding?: string): Promise<string>;
    /**
     * pipes response stream to given target stream
     * @param stream target stream
     * @param end if `true` closes stream after finishing
     */
    pipe(stream: NodeJS.WritableStream, end?: boolean): Promise<string>;
    private _exMap;
    /**
     * use to set your custom error message mapping
     * @param fn map function
     */
    exMap(fn: (ex: Error, data?: string) => Error): this;
}
